FrankFrank.Weibull.data: Generate data from the Frank copula for serial dependence and the Frank copula for dependent censoring with the Weibull distributions
Description
The data generation process is based on the Frank copula C_theta for serial dependence and the Frank copula tilde(C)_alpha for dependent censoring with the marginal distributions Weib(scale1, shape1) and Weib(scale2, shape2). Censoring percentage can be controlled by constant c. This function is used when doing parametric bootstrap. The guide for using this function shall be explained by Huang (2019), and Huang, Wang and Emura (2020).
scale parameter for Weib(scale1, shape1), scale1 > 0
shape1
shape parameter for Weib(scale1, shape1), shape1 > 0
theta
copula parameter for C_theta, theta \(\neq\) 0
scale2
scale parameter for Weib(scale2, shape2), scale2 > 0
shape2
shape parameter for Weib(scale2, shape2), shape2 > 0
alpha
copula parameter for tilde(C)_alpha, alpha \(\neq\) 0
b
parameter of Unif(0, b) for controlling censoring percentage
l
length for data generation (default = 300)
Value
A list with the following elements:
Subject
a vector for numbers of subject
T_ij
a vector for event times
delta_ij
a vector for event indicator (=1 if recurrent; =0 if censoring)
T_i_star
a vector for death times
delta_i_star
a vector for death indicator (=1 if death; =0 if censoring)
References
Huang XW, Wang W, Emura T (2020) A copula-based Markov chain model for serially dependent event times with a dependent terminal event. Japanese Journal of Statistics & Data Science. Accepted.